```
Usage: vcd gateway configure-default-gateway update [OPTIONS] <gateway name>

Options:
  -e, --external-network <external network>
                                  external network connected to the gateway.
                                  [required]
  -i, --gateway-ip <ip>           IP of the gateway.  [required]
  --enable / --disable            enables/disables the default gateway
  -h, --help                      Show this message and exit.

```
